@@ -8,9 +8,13 @@ BASE_URL_KEY = "LAUNCHABLE_BASE_URL"
 DEFAULT_BASE_URL = "https://api.mercury.launchableinc.com"
 
 
+def get_base_url():
+    return os.getenv(BASE_URL_KEY) or DEFAULT_BASE_URL
+
+
 class LaunchableClient:
     def __init__(self, token, base_url="", http=requests):
-        self.base_url = base_url or os.getenv(BASE_URL_KEY) or DEFAULT_BASE_URL
+        self.base_url = base_url or get_base_url()
         self.http = http
         self.token = token
 
